==> ae_gui-0.3.109.tar.gz: ae_gui-0.3.109/README.md <==
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project ae.ae V0.3.95 -->
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project aedev.tpl_namespace_root V0.3.14 -->
# gui 0.3.109

[![GitLab develop](https://img.shields.io/gitlab/pipeline/ae-group/ae_gui/develop?logo=python)](
    https://gitlab.com/ae-group/ae_gui)
[![LatestPyPIrelease](
    https://img.shields.io/gitlab/pipeline/ae-group/ae_gui/release?logo=python)](
    https://gitlab.com/ae-group/ae_gui/-/tree/release)
[![PyPIVersions](https://img.shields.io/pypi/v/ae_gui)](
    https://pypi.org/project/ae-gui/#history)

>ae_gui package 0.3.109.

[![Coverage](https://ae-group.gitlab.io/ae_gui/coverage.svg)](
    https://ae-group.gitlab.io/ae_gui/coverage/index.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_gui/mypy.svg)](
    https://ae-group.gitlab.io/ae_gui/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_gui/pylint.svg)](
    https://ae-group.gitlab.io/ae_gui/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_gui)](
    https://gitlab.com/ae-group/ae_gui/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_gui)](
    https://gitlab.com/ae-group/ae_gui/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_gui)](
    https://gitlab.com/ae-group/ae_gui/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_gui)](
    https://pypi.org/project/ae-gui/)
[![PyPILicense](https://img.shields.io/pypi/l/ae_gui)](
    https://gitlab.com/ae-group/ae_gui/-/blob/develop/LICENSE.md)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_gui)](
    https://libraries.io/pypi/ae-gui)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_gui)](
    https://pypi.org/project/ae-gui/#files)


## installation


execute the following command to install the
ae.gui package
in the currently active virtual environment:
 
```shell script
pip install ae-gui
```

if you want to contribute to this portion then first fork
[the ae_gui repository at GitLab](
https://gitlab.com/ae-group/ae_gui "ae.gui code repository").
after that pull it to your machine and finally execute the
following command in the root folder of this repository
(ae_gui):

```shell script
pip install -e .[dev]
```

the last command will install this package portion, along with the tools you need
to develop and run tests or to extend the portion documentation. to contribute only to the unit tests or to the
documentation of this portion, replace the setup extras key `dev` in the above command with `tests` or `docs`
respectively.

more detailed explanations on how to contribute to this project
[are available here](
https://gitlab.com/ae-group/ae_gui/-/blob/develop/CONTRIBUTING.rst)


## namespace portion documentation

information on the features and usage of this portion are available at
[ReadTheDocs](
https://ae.readthedocs.io/en/latest/_autosummary/ae.gui.html
"ae_gui documentation").

==> ae_gui-0.3.110.tar.gz: ae_gui-0.3.110/README.md <==
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project ae.ae V0.3.95 -->
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project aedev.tpl_namespace_root V0.3.14 -->
# gui 0.3.110

[![GitLab develop](https://img.shields.io/gitlab/pipeline/ae-group/ae_gui/develop?logo=python)](
    https://gitlab.com/ae-group/ae_gui)
[![LatestPyPIrelease](
    https://img.shields.io/gitlab/pipeline/ae-group/ae_gui/release0.3.109?logo=python)](
    https://gitlab.com/ae-group/ae_gui/-/tree/release0.3.109)
[![PyPIVersions](https://img.shields.io/pypi/v/ae_gui)](
    https://pypi.org/project/ae-gui/#history)

>ae_gui package 0.3.110.

[![Coverage](https://ae-group.gitlab.io/ae_gui/coverage.svg)](
    https://ae-group.gitlab.io/ae_gui/coverage/index.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_gui/mypy.svg)](
    https://ae-group.gitlab.io/ae_gui/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_gui/pylint.svg)](
    https://ae-group.gitlab.io/ae_gui/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_gui)](
    https://gitlab.com/ae-group/ae_gui/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_gui)](
    https://gitlab.com/ae-group/ae_gui/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_gui)](
    https://gitlab.com/ae-group/ae_gui/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_gui)](
    https://pypi.org/project/ae-gui/)
[![PyPILicense](https://img.shields.io/pypi/l/ae_gui)](
    https://gitlab.com/ae-group/ae_gui/-/blob/develop/LICENSE.md)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_gui)](
    https://libraries.io/pypi/ae-gui)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_gui)](
    https://pypi.org/project/ae-gui/#files)


## installation


execute the following command to install the
ae.gui package
in the currently active virtual environment:
 
```shell script
pip install ae-gui
```

if you want to contribute to this portion then first fork
[the ae_gui repository at GitLab](
https://gitlab.com/ae-group/ae_gui "ae.gui code repository").
after that pull it to your machine and finally execute the
following command in the root folder of this repository
(ae_gui):

```shell script
pip install -e .[dev]
```

the last command will install this package portion, along with the tools you need
to develop and run tests or to extend the portion documentation. to contribute only to the unit tests or to the
documentation of this portion, replace the setup extras key `dev` in the above command with `tests` or `docs`
respectively.

more detailed explanations on how to contribute to this project
[are available here](
https://gitlab.com/ae-group/ae_gui/-/blob/develop/CONTRIBUTING.rst)


## namespace portion documentation

information on the features and usage of this portion are available at
[ReadTheDocs](
https://ae.readthedocs.io/en/latest/_autosummary/ae.gui.html
"ae_gui documentation").
